@@ -587,6 +587,14 @@ suspend_oleo ()
   if (using_curses)
     {
       stop_curses ();
+#ifdef SIGTSTP
+      kill (getpid (), SIGTSTP);
+#else
+#ifdef SIGSTOP
+       kill (getpid (), SIGSTOP);
+#endif
+#endif
+      cont_curses ();
       kill (getpid (), SIGSTOP);
     }
 }
@@ -1612,7 +1620,7 @@ goto_edit_cell (c)
 #endif
 {
   pushed_back_char = c;
-  execute_command ("edit-cell", 1);
+  execute_command ("edit-cell");
 }
 
 
@@ -1638,7 +1646,7 @@ read_cmds_cmd (fp)
       for (ptr = line.buf; isspace (*ptr); ptr++);
       if (!*ptr || (*ptr == '#'))
 	continue;
-      execute_command (ptr, 1);
+      execute_command (ptr);
     }
 }
 
@@ -1669,7 +1677,7 @@ read_file_and_run_hooks (fp, ismerge, name)
       struct var * v;
       v = find_var (load_hooks_string, sizeof (load_hooks_string) - 1);
       if (v && v->var_flags != VAR_UNDEF)
-	execute_command (load_hooks_string, 1);
+	execute_command (load_hooks_string);
     }
 }
 
@@ -1862,7 +1870,8 @@ set_region_protection (rng, prot)
      int prot;
 #endif
 {
-  prot = tolower (prot);
+  if (isupper (prot))
+    prot = tolower (prot);
   switch (prot)
     {
     case 'd':
@@ -1932,7 +1941,7 @@ set_def_height (height)
       || words_imatch (&height, "d")
       || words_imatch (&height, "def")
       || words_imatch (&height, "default"))
-    hgt = 0;
+    hgt = 1;
   else
     {
       hgt = astol (&height);
@@ -1998,7 +2007,8 @@ set_def_protection (prot)
      int prot;
 #endif
 {
-  prot = tolower (prot);
+  if (isupper (prot))
+    prot = tolower (prot);
   switch (prot)
     {
     case 'p':
@@ -2128,6 +2138,11 @@ auto_next_set ()
 #endif
 {
   scan_cell_cursor (opposite_motion[auto_motion_direction], 1);
+  {
+    CELL * cp = find_cell (curow, cucol);
+    if (!cp || !GET_TYP(cp))
+      shift_cell_cursor (auto_motion_direction, 1);
+  }
   shift_cell_cursor (complementary_motion[auto_motion_direction], 1);
 }
 
