@@ -27,7 +27,6 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #include "global.h"
 #include "node.h"
 #include "eval.h"
-#include "math.h"
 #include "hash.h"
 #include "ref.h"
 
@@ -173,7 +172,11 @@ struct function the_funs[] =
   {C_FN1, X_A1, "R", 0, "rows"},
   {C_FN1, X_A1, "R", 0, "cols"},
   {C_FN2, X_A2, "FF", V atan2, "atan2"},
+#ifdef HAVE_HYPOT
   {C_FN2, X_A2, "FF", V hypot, "hypot"},
+#else
+  {C_FN2, X_A2, "FF", 0, "*&%$%*"},
+#endif
   {C_FN2, X_A2, "FI", 0, "fixed"},
   {C_FN2, X_A2, "AA", 0, "iferr"},
   {C_FN2, X_A2, "RI", 0, "index"},
