@@ -17,7 +17,7 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
 
 #include <ctype.h>
-#include "errno.h"
+#include <errno.h>
 #define obstack_chunk_alloc ck_malloc
 #define obstack_chunk_free free
 #include "obstack.h"
@@ -243,21 +243,26 @@ bound_macro (num)
 
 #ifdef __STDC__
 void
-run_string_as_macro (char * macro, int count)
+run_string_as_macro (char * macro)
 #else
 void
-run_string_as_macro (macro, count)
+run_string_as_macro (macro)
      char * macro;
-     int count;
 #endif
 {
   struct rng rng;
-  while (count--)
-    {
-      rng.lr = rng.hr = rng.lc = rng.hc = MIN_ROW;
-      macro_only_input_stream (&rng, macro, strlen (macro), the_cmd_frame);
-      command_loop (1);
-    }
+  /* This is going to continue the command loop
+   * as if some other command had been executed.
+   * That command shouldn't receive the same prefix
+   * arg that provided a repeat count.
+   */
+  how_many = 1;
+  set_line (&raw_prefix, "");
+  rng.lr = rng.hr = rng.lc = rng.hc = MIN_ROW;
+  /* Reset the keystate. */
+  cur_keymap = the_cmd_frame->top_keymap;
+  macro_only_input_stream (&rng, macro, strlen (macro), the_cmd_frame);
+  command_loop (1);
 }
 
 #ifdef __STDC__
@@ -271,7 +276,8 @@ call_last_kbd_macro (count)
 {
   if (!last_macro)
     io_error_msg ("No keyboard macro entered.");
-  run_string_as_macro ((char *)last_macro, count);
+  while (count-- > 0)
+    run_string_as_macro ((char *)last_macro);
 }
 
 /* This command is automaticly inserted into the command stream
@@ -513,7 +519,7 @@ int
 real_get_chr ()
 #endif
 {
-  int ch;			/* The char that will be returned. */
+  int ch = EOF;			/* The char that will be returned. */
 
   /* Characters with the meta bit set are returned as
    * two characters: ESC and a non-meta character.
@@ -552,7 +558,6 @@ real_get_chr ()
       io_scan_for_input (0);
       if (!io_input_avail ())
 	{
-	  ++current_cycle;
 	  if (auto_recalc && eval_next_cell ())
 	    {
 	      if (bkgrnd_recalc)
@@ -575,7 +580,6 @@ real_get_chr ()
 				: (alarm_seconds / 2))
 			     : 0);
 			     
-	      --current_cycle;
 	      io_redisp ();
 	      io_flush ();
 	      io_scan_for_input (0);
@@ -900,7 +904,7 @@ recover_from_error ()
     obstack_init (&stream->_macro_stack);
     stream->_rmac = 0;
     stream->_func_arg = 0;
-    stream->_macro = stream->_macro_start = 0;
+    stream->_macro = stream->_macro_start = stream->_last_macro = 0;
     stream->_macro_size = 0;
     stream->_pushed_back_char = -1;
   }
@@ -1128,7 +1132,6 @@ command_loop (prefix)
 	push_command_frame (0, 0, 0);
 
       /* Reset the prefix argument. */
-
       how_many = 1;
       set_line (&raw_prefix, "");
       io_update_status ();
@@ -1896,22 +1899,6 @@ command_loop (prefix)
 
 static struct line exec_cmd_line = {0, 0};
 
-#ifdef __STDC__
-void
-execute_as_macro (char * str)
-#else
-void
-execute_as_macro (str)
-     char * str;
-#endif
-{
-  struct rng fake_rng;
-  fake_rng.lr = fake_rng.lc = fake_rng.hr = fake_rng.hc = 1;
-  macro_only_input_stream (&fake_rng, str, strlen (str), the_cmd_frame);
-  command_loop (1);
-}
-
-
 /* execute_command buils a macro expression of the from `{command args}'.
  * This function quotes the braces in ARGS so that the macro reader knows
  * they are literal rather than macro syntax.
@@ -1937,12 +1924,11 @@ quote_macro_args (args)
 
 #ifdef __STDC__
 void 
-execute_command (char *str, int count)
+execute_command (char *str)
 #else
 void 
-execute_command (str, count)
+execute_command (str)
      char *str;
-     int count;
 #endif
 {
   char *ptr = str;
@@ -1952,22 +1938,27 @@ execute_command (str, count)
    * set to a one cell region.
    */
   struct rng rng;
+  static struct line exec_buf = {0, 0};
+  int count = 1;
 
   /* Chop off the first word. */
   while (isspace (*str))
     ++str;
   if (!*str || *str == '#')
     return;
-  for (ptr = str; *ptr && *ptr != ' '; ptr++);
-  
+  for (ptr = str; *ptr && !isspace (*ptr); ptr++);
   if (*ptr)
-    *ptr++ = '\0';
+    {
+      setn_line (&exec_buf, str, ptr - str + 1);
+      exec_buf.buf[ptr - str] = 0;
+      str  = exec_buf.buf;
+      ++ptr;
+    }
   else
     ptr = 0;
   
 
   /* First, look for a command name. */
-  
   {
     int vector;
     struct cmd_func * cmd;
@@ -2012,13 +2003,15 @@ execute_command (str, count)
       }
 
     run = cp->cell_str;
+    /* Reset the keystate. */
+    cur_keymap = the_cmd_frame->top_keymap;
     count = how_many;
-    how_many = 1;
-    set_line (&raw_prefix, "");
+    how_many = 1;		/* s.o.p when executing macros; */
+    set_line (&raw_prefix, "");	/* see run_string_as_macro for more info*/
   }
 
  found_command:
-  while (count --)
+  while (count-- > 0)
     {
       macro_only_input_stream (&rng, run, strlen (run), the_cmd_frame);
       command_loop (1);
@@ -2124,7 +2117,7 @@ io_error_msg (str, va_alist)
   sprintf (buf2, "display-error-msg %s", buf);
   recover_from_error ();
   if (display_opened)
-    execute_command (buf2, 1);
+    execute_command (buf2);
   else
     fprintf (stderr, "oleo: %s\n", buf);
   longjmp (error_exception, 1);
@@ -2148,7 +2141,7 @@ io_info_msg (str, va_alist)
   var_start (foo, str);
   vsprintf (buf, str, foo);
   sprintf (buf2, "display-error-msg %s", buf);
-  execute_command (buf2, 1);
+  execute_command (buf2);
 }
 
 
@@ -2355,5 +2348,5 @@ one_cmd_with_keymap (mapname, keyseq)
        keyseq->keys->buf, map_names[keyseq->cmd.code]);
   else
     execute_command
-      (the_funcs[keyseq->cmd.vector][keyseq->cmd.code].func_name, 1);
+      (the_funcs[keyseq->cmd.vector][keyseq->cmd.code].func_name);
 }
