@@ -72,7 +72,7 @@ n_alloc (size, tightness, fmt, va_alist)
   return ret;
 }
 
-#define n_free(x)	free(x)
+#define n_free(x)	ck_free(x)
 
 static struct pr_node *
 byte_decompile (expr)
