@@ -413,7 +413,7 @@ DEFUN_3 ("stop-entering-macro", FDstop_entering_macro, stop_entering_macro)
 "Finish defining a keyboard macro.",
 "The definition was started by [start-entering-macro]",
 "The macro is now available for use via [call-last-kbd-macro]",
-"or it can be given a name with [store_last_macro] and then invoked",
+"or it can be given a name with [store-last-macro] and then invoked",
 "by passing it's cell address to [execute-command].",
 #if 0
 "With numeric arg, repeat macro now that many times,",
@@ -429,7 +429,7 @@ DEFUN ("call-last-kbd-macro", FDcall_last_kbd_macro,
 #ifdef DOC_STRINGS
 "Call the last keyboard macro that you defined with [start-entering-macro].",
 "To make a macro permanent so you can call it even after",
-"defining others, use [store-last-kbd-macro].",
+"defining others, use [store-last-macro].",
 #endif
 
 DEFUN_3 ("end-macro", FDend_macro, end_macro)
@@ -452,11 +452,10 @@ DEFUN ("store-last-macro",
 DEFUN ("run-string-as-macro",
        FDrun_string_as_macro, FArun_string_as_macro, run_string_as_macro)
 #ifdef FUNC_ARG_STRINGS
-"sRun macro string: "
-"p",
+"sRun macro string: ",
 #endif
 #ifdef DOC_STRINGS
-"Execute STRING as a keyboard macro PREFIX times.",
+"Execute STRING as a keyboard macro.",
 #endif
 
 DEFUN ("name-macro-string",
@@ -717,11 +716,11 @@ DEFUN ("read-commands", FDread_cmds_cmd, FAread_cmds_cmd, read_cmds_cmd)
 #ifdef DOC_STRINGS
 "Read Oleo commands from FILE.",
 "The syntax for a command is a command name followed by a whitespace",
-"separated list arguments.  For example? ",
+"separated list arguments.  For example: ",
 "	bind-key main next-row ^n",
 "Blank lines and lines that begin with `#' are ignored.",
-"Lines may be continuted by precediing the final newline with an",
-"odd number of `\' characters.  One backslash and the newline will",
+"Lines may be continuted by preceeding the final newline with an",
+"odd number of `\\' characters.  One backslash and the newline will",
 "be discarded.",
 #endif
 
@@ -783,7 +782,7 @@ DEFUN ("merge-spreadsheet",
 DEFUN ("write-region-to-file",
        FDwrite_reg_cmd, FAwrite_reg_cmd, write_reg_cmd)
 #ifdef FUNC_ARG_STRINGS
-"***r",
+"rWrite region? ",
 "fwWrite region to file? ",
 #endif
 #ifdef DOC_STRINGS
@@ -869,7 +868,7 @@ DEFUN ("delete-col", FDdelete_col, FAdelete_col, delete_col)
 
 
 
-/* Commands for editting cells. */
+/* Commands for editing cells. */
 
 DEFUN ("edit-cell", FDedit_cell, FAedit_cell, edit_cell)
 #ifdef FUNC_ARG_STRINGS
@@ -879,6 +878,14 @@ DEFUN ("edit-cell", FDedit_cell, FAedit_cell, edit_cell)
 "Assign FORMULA to the current cell.",
 #endif
 
+DEFUN ("set-cell", FDset_cell, FAset_cell, edit_cell)
+#ifdef FUNC_ARG_STRINGS
+"sSet %c to? ", 
+#endif
+#ifdef DOC_STRINGS
+"Assign FORMULA to the current cell.",
+#endif
+
 DEFUN ("auto-move-up", FDauto_move_up, FAauto_move_up,
        set_auto_direction)
 #ifdef FUNC_ARG_STRINGS
@@ -980,7 +987,7 @@ DEFUN ("auto-move-no-motion", FDauto_move_no_motion, FAauto_move_no_motion,
 DEFUN_3 ("auto-move", FDauto_move, auto_move)
 #ifdef DOC_STRINGS
 "Move one cell in the automatic motion direction.",
-"The automatic motion direction is set using one of the commands? ",
+"The automatic motion direction is set using one of the commands: ",
 "	[auto-move-up]  auto-move-up",
 "	[auto-move-down]  auto-move-down",
 "	[auto-move-left]  auto-move-left",
@@ -1001,10 +1008,9 @@ DEFUN_3 ("auto-next-set", FDauto_next_set, auto_next_set)
 DEFUN ("next-edit", FDnext_edit, FAnext_edit, run_string_as_macro)
 #ifdef FUNC_ARG_STRINGS
 "={exit-minibuffer}{auto-move}{edit-cell}",
-"p",
 #endif
 #ifdef DOC_STRINGS
-"Equivelent to: {exit-minibuffer}{auto-move}{edit-cell}",
+"Equivalent to: {exit-minibuffer}{auto-move}{edit-cell}",
 "This command is used to terminate an edit-cell command, move to another",
 "cell, and begin a second edit-cell command.  See also `auto-move'.",
 #endif
@@ -1012,10 +1018,9 @@ DEFUN ("next-edit", FDnext_edit, FAnext_edit, run_string_as_macro)
 DEFUN ("next-edit-set", FDnext_edit_set, FAnext_edit_set, run_string_as_macro)
 #ifdef FUNC_ARG_STRINGS
 "={exit-minibuffer}{auto-next-set}{edit-cell}",
-"p",
 #endif
 #ifdef DOC_STRINGS
-"Equivelent to: {exit-minibuffer}{auto-next-set}{edit-cell}",
+"Equivalent to: {exit-minibuffer}{auto-next-set}{edit-cell}",
 "This command is used to terminate an edit-cell command, move to another",
 "cell, and begin a second edit-cell command.  See also `auto-next-set'.",
 #endif
@@ -1030,7 +1035,7 @@ DEFUN ("goto-edit-cell",
 #ifdef DOC_STRINGS
 "Begin to edit the current cell's formula.",
 "The last character used to invoke this command is reexecuted as a",
-"formula editting command.",
+"formula editing command.",
 #endif
 
 DEFUN ("set-region-formula",
@@ -1107,7 +1112,7 @@ DEFUN ("set-page-size", FDset_page_size, FAset_page_size, set_page_size_cmd)
 "`print.c'.",
 #endif
 
-DEFUN ("set-deault-ps-font",
+DEFUN ("set-default-ps-font",
        FDset_ps_font_cmd, FAset_ps_font_cmd, set_ps_font_cmd)
 #ifdef FUNC_ARG_STRINGS
 "sSet default postscript font? ",
@@ -1128,7 +1133,7 @@ DEFUN ("set-default-x-font",
 #ifdef DOC_STRINGS
 "Make FONT the default X11 font.",
 "FONT should be a valid X11 font name, with the point size wildcarded.",
-"For example? ",
+"For example: ",
 "		*times-medium-r-*",
 "",
 "This will be used to display all cells with no explicitly defined font.",
@@ -1156,17 +1161,17 @@ DEFUN ("define-font", FDdefine_font, FAdefine_font, define_font)
 #endif
 #ifdef DOC_STRINGS
 "Define the font OLEONAME to correspond to X11NAME and POSTSCRIPTNAME.",
-""
+"",
 "The Oleo name of a font is used with commands like set-region-font.",
-"It should be easy to type and to remember, for example? ",
+"It should be easy to type and to remember, for example: ",
 "",
 "		times",
 "",
 "To achieve the best results, the X11 font name should leave the",
-"pointsize wild-carded.  For example? ",
+"pointsize wild-carded.  For example: ",
 "",
 "		*times-medium-r-*",
-""
+"",
 "The postscript name should be a font name acceptable to your printer.",
 "For example:",
 "",
@@ -1264,7 +1269,7 @@ DEFUN ("open-window", FDopen_window, FAopen_window, open_window)
 "Split the window according to SPLIT.",
 "The syntax of split is an orientation (`h' or `v') followed by",
 "either a number of rows (cols) or a percentege of rows (cols).",
-"For example? ",
+"For example: ",
 "	h10",
 "	v33%",
 #endif
@@ -1328,7 +1333,7 @@ DEFUN ("toggle-overwrite", FDtoggle_overwrite, FAtoggle_overwrite, toggle_overwr
 #endif
 #ifdef DOC_STRINGS
 "Toggle between insert and overwrite mode.",
-"This command only applies when an argument is being editted.",
+"This command only applies when an argument is being edited.",
 "",
 "With a positive (non-0) prefix argument, turn overwrite mode on.",
 "With a negative or 0 prefix argument, turn overwrite mode off.",
@@ -1443,7 +1448,7 @@ DEFUN_3 ("insert-cell-value", FDinsert_cell_value, insert_cell_value)
 DEFUN_3 ("insert-rel-ref", FDinsert_rel_ref, insert_rel_ref)
 #ifdef DOC_STRINGS
 "Insert a relative reference in the input area.",
-"This command can only be executed when a cell formula is being editted.",
+"This command can only be executed when a cell formula is being edited.",
 "The inserted references is to the current cell, and is relative to the",
 "cell being defined.",
 #endif
@@ -1519,7 +1524,7 @@ DEFUN ("self-map-command",
 "l",
 #endif
 #ifdef DOC_STRINGS
-"Map the last-typed character in the keysequence argument being editted.",
+"Map the last-typed character in the keysequence argument being edited.",
 "This is used by the help system to prompt for the argument to describe-key and",
 "describe-key-briefly.",
 #endif
@@ -1772,7 +1777,7 @@ DEFUN_5 ("set-cell-format", FDset_cell_format, FAset_cell_format,
 DEFUN ("set-default-height",
        FDset_def_height, FAset_def_height, set_def_height)
 #ifdef FUNC_ARG_STRINGS
-"nDefault height? ",
+"sDefault height? ",
 #endif
 #ifdef DOC_STRINGS
 "Set the default height of rows.",
@@ -2109,7 +2114,7 @@ DEFUN ("graph-set-axis-low",
        FDgraph_set_axis_low, FAgraph_set_axis_low, graph_set_axis_lo)
 #ifdef FUNC_ARG_STRINGS
 "[xXyY]Set range start for which axis? (`x' or `y') ",
-"sBeginning of the X axis range [a number or `def']? ",
+"sBeginning of the %0 axis range [a number or `def']? ",
 #endif
 #ifdef DOC_STRINGS
 "Set the beginning of the range graph on AXIS to LOW.",
@@ -2120,7 +2125,7 @@ DEFUN ("graph-set-axis-high",
        FDgraph_set_axis_high, FAgraph_set_axis_high, graph_set_axis_hi)
 #ifdef FUNC_ARG_STRINGS
 "[xXyY]Set range start for which axis? (`x' or `y') ",
-"sBeginning of the X axis range [a number or `def']? ",
+"sEnd of the %0 axis range [a number or `def']? ",
 #endif
 #ifdef DOC_STRINGS
 "Set the beginning of the range graph on AXIS to HIGH.",
@@ -2148,7 +2153,7 @@ DEFUN ("graph-set-x-axis-symbolic", FDgraph_set_axis_symbolic,
 "will be be proviced with X coordinates from RANGE in the specified order.",
 "",
 "For non-symbolic ranges, use [graph-set-axis-low]",
-""
+"",
 "For symbolic labels on a numeric range, use [graph-set-axis-labels]",
 #endif
 
