@@ -1,5 +1,5 @@
 
-/*  A Bison parser, made from getdate.y  */
+/*  A Bison parser, made from ./getdate.y  */
 
 #define YYBISON 1  /* Identify Bison output.  */
 
@@ -17,7 +17,7 @@
 #define	tZONE	269
 #define	tDST	270
 
-#line 1 "getdate.y"
+#line 1 "./getdate.y"
 
 /* $Revision: 2.1 $
 **
@@ -102,7 +102,7 @@ struct timeb {
 
 #endif	/* defined(vms) */
 
-#if defined (STDC_HEADERS) || defined (USG)
+#if defined (STDC_HEADERS) || defined (HAVE_STRING_H)
 #include <string.h>
 #endif
 
@@ -179,7 +179,7 @@ static time_t	gtdRelMonth;
 static time_t	gtdRelSeconds;
 
 
-#line 163 "getdate.y"
+#line 163 "./getdate.y"
 typedef union {
     time_t		Number;
     enum _MERIDIAN	Meridian;
@@ -787,37 +787,37 @@ gtdreduce:
   switch (gtdn) {
 
 case 3:
-#line 181 "getdate.y"
+#line 181 "./getdate.y"
 {
 	    gtdHaveTime++;
 	;
     break;}
 case 4:
-#line 184 "getdate.y"
+#line 184 "./getdate.y"
 {
 	    gtdHaveZone++;
 	;
     break;}
 case 5:
-#line 187 "getdate.y"
+#line 187 "./getdate.y"
 {
 	    gtdHaveDate++;
 	;
     break;}
 case 6:
-#line 190 "getdate.y"
+#line 190 "./getdate.y"
 {
 	    gtdHaveDay++;
 	;
     break;}
 case 7:
-#line 193 "getdate.y"
+#line 193 "./getdate.y"
 {
 	    gtdHaveRel++;
 	;
     break;}
 case 9:
-#line 199 "getdate.y"
+#line 199 "./getdate.y"
 {
 	    gtdHour = gtdvsp[-1].Number;
 	    gtdMinutes = 0;
@@ -826,7 +826,7 @@ case 9:
 	;
     break;}
 case 10:
-#line 205 "getdate.y"
+#line 205 "./getdate.y"
 {
 	    gtdHour = gtdvsp[-3].Number;
 	    gtdMinutes = gtdvsp[-1].Number;
@@ -835,7 +835,7 @@ case 10:
 	;
     break;}
 case 11:
-#line 211 "getdate.y"
+#line 211 "./getdate.y"
 {
 	    gtdHour = gtdvsp[-3].Number;
 	    gtdMinutes = gtdvsp[-1].Number;
@@ -845,7 +845,7 @@ case 11:
 	;
     break;}
 case 12:
-#line 218 "getdate.y"
+#line 218 "./getdate.y"
 {
 	    gtdHour = gtdvsp[-5].Number;
 	    gtdMinutes = gtdvsp[-3].Number;
@@ -854,7 +854,7 @@ case 12:
 	;
     break;}
 case 13:
-#line 224 "getdate.y"
+#line 224 "./getdate.y"
 {
 	    gtdHour = gtdvsp[-5].Number;
 	    gtdMinutes = gtdvsp[-3].Number;
@@ -865,56 +865,56 @@ case 13:
 	;
     break;}
 case 14:
-#line 234 "getdate.y"
+#line 234 "./getdate.y"
 {
 	    gtdTimezone = gtdvsp[0].Number;
 	    gtdDSTmode = DSToff;
 	;
     break;}
 case 15:
-#line 238 "getdate.y"
+#line 238 "./getdate.y"
 {
 	    gtdTimezone = gtdvsp[0].Number;
 	    gtdDSTmode = DSTon;
 	;
     break;}
 case 16:
-#line 243 "getdate.y"
+#line 243 "./getdate.y"
 {
 	    gtdTimezone = gtdvsp[-1].Number;
 	    gtdDSTmode = DSTon;
 	;
     break;}
 case 17:
-#line 249 "getdate.y"
+#line 249 "./getdate.y"
 {
 	    gtdDayOrdinal = 1;
 	    gtdDayNumber = gtdvsp[0].Number;
 	;
     break;}
 case 18:
-#line 253 "getdate.y"
+#line 253 "./getdate.y"
 {
 	    gtdDayOrdinal = 1;
 	    gtdDayNumber = gtdvsp[-1].Number;
 	;
     break;}
 case 19:
-#line 257 "getdate.y"
+#line 257 "./getdate.y"
 {
 	    gtdDayOrdinal = gtdvsp[-1].Number;
 	    gtdDayNumber = gtdvsp[0].Number;
 	;
     break;}
 case 20:
-#line 263 "getdate.y"
+#line 263 "./getdate.y"
 {
 	    gtdMonth = gtdvsp[-2].Number;
 	    gtdDay = gtdvsp[0].Number;
 	;
     break;}
 case 21:
-#line 267 "getdate.y"
+#line 267 "./getdate.y"
 {
 	    gtdMonth = gtdvsp[-4].Number;
 	    gtdDay = gtdvsp[-2].Number;
@@ -922,7 +922,7 @@ case 21:
 	;
     break;}
 case 22:
-#line 272 "getdate.y"
+#line 272 "./getdate.y"
 {
 	    /* ISO 8601 format.  gtdgtd-mm-dd.  */
 	    gtdYear = gtdvsp[-2].Number;
@@ -931,14 +931,14 @@ case 22:
 	;
     break;}
 case 23:
-#line 278 "getdate.y"
+#line 278 "./getdate.y"
 {
 	    gtdMonth = gtdvsp[-1].Number;
 	    gtdDay = gtdvsp[0].Number;
 	;
     break;}
 case 24:
-#line 282 "getdate.y"
+#line 282 "./getdate.y"
 {
 	    gtdMonth = gtdvsp[-3].Number;
 	    gtdDay = gtdvsp[-2].Number;
@@ -946,14 +946,14 @@ case 24:
 	;
     break;}
 case 25:
-#line 287 "getdate.y"
+#line 287 "./getdate.y"
 {
 	    gtdMonth = gtdvsp[0].Number;
 	    gtdDay = gtdvsp[-1].Number;
 	;
     break;}
 case 26:
-#line 291 "getdate.y"
+#line 291 "./getdate.y"
 {
 	    gtdMonth = gtdvsp[-1].Number;
 	    gtdDay = gtdvsp[-2].Number;
@@ -961,68 +961,68 @@ case 26:
 	;
     break;}
 case 27:
-#line 298 "getdate.y"
+#line 298 "./getdate.y"
 {
 	    gtdRelSeconds = -gtdRelSeconds;
 	    gtdRelMonth = -gtdRelMonth;
 	;
     break;}
 case 29:
-#line 305 "getdate.y"
+#line 305 "./getdate.y"
 {
 	    gtdRelSeconds += gtdvsp[-1].Number * gtdvsp[0].Number * 60L;
 	;
     break;}
 case 30:
-#line 308 "getdate.y"
+#line 308 "./getdate.y"
 {
 	    gtdRelSeconds += gtdvsp[-1].Number * gtdvsp[0].Number * 60L;
 	;
     break;}
 case 31:
-#line 311 "getdate.y"
+#line 311 "./getdate.y"
 {
 	    gtdRelSeconds += gtdvsp[0].Number * 60L;
 	;
     break;}
 case 32:
-#line 314 "getdate.y"
+#line 314 "./getdate.y"
 {
 	    gtdRelSeconds += gtdvsp[-1].Number;
 	;
     break;}
 case 33:
-#line 317 "getdate.y"
+#line 317 "./getdate.y"
 {
 	    gtdRelSeconds += gtdvsp[-1].Number;
 	;
     break;}
 case 34:
-#line 320 "getdate.y"
+#line 320 "./getdate.y"
 {
 	    gtdRelSeconds++;
 	;
     break;}
 case 35:
-#line 323 "getdate.y"
+#line 323 "./getdate.y"
 {
 	    gtdRelMonth += gtdvsp[-1].Number * gtdvsp[0].Number;
 	;
     break;}
 case 36:
-#line 326 "getdate.y"
+#line 326 "./getdate.y"
 {
 	    gtdRelMonth += gtdvsp[-1].Number * gtdvsp[0].Number;
 	;
     break;}
 case 37:
-#line 329 "getdate.y"
+#line 329 "./getdate.y"
 {
 	    gtdRelMonth += gtdvsp[0].Number;
 	;
     break;}
 case 38:
-#line 334 "getdate.y"
+#line 334 "./getdate.y"
 {
 	    if (gtdHaveTime && gtdHaveDate && !gtdHaveRel)
 		gtdYear = gtdvsp[0].Number;
@@ -1051,13 +1051,13 @@ case 38:
 	;
     break;}
 case 39:
-#line 362 "getdate.y"
+#line 362 "./getdate.y"
 {
 	    gtdval.Meridian = MER24;
 	;
     break;}
 case 40:
-#line 365 "getdate.y"
+#line 365 "./getdate.y"
 {
 	    gtdval.Meridian = gtdvsp[0].Meridian;
 	;
@@ -1257,7 +1257,7 @@ gtderrhandle:
   gtdstate = gtdn;
   goto gtdnewstate;
 }
-#line 370 "getdate.y"
+#line 370 "./getdate.y"
 
 
 /* Month and day table. */
