@@ -137,7 +137,8 @@ chr_to_axis (c)
      int c;
 #endif
 {
-  c = tolower (c);
+  if (isupper (c))
+    c = tolower (c);
   switch (c)
     {
     case 'x':
@@ -159,7 +160,8 @@ chr_to_graph_ordering (c)
      int c;
 #endif
 {
-  c = tolower (c);
+  if (isupper (c))
+    c = tolower (c);
   switch (c)
     {
     case 'r':
@@ -182,8 +184,10 @@ chrs_to_graph_pair_ordering (pair, dir)
 #endif
 {
   int pair_offset;
-  pair = tolower (pair);
-  dir = tolower (dir);
+  if (isupper (pair))
+    pair = tolower (pair);
+  if (isupper (dir))
+    dir = tolower (dir);
 
   switch (pair)
     {
@@ -278,8 +282,10 @@ graph_postscript (file, kind, spectrum, font, pt_size)
      int pt_size;
 #endif
 {
-  kind = tolower (kind);
-  spectrum = tolower (spectrum);
+  if (isupper (kind))
+    kind = tolower (kind);
+  if (isupper (spectrum))
+    spectrum = tolower (spectrum);
   if (!index ("led", kind))
     io_error_msg
       ("Incorrect postscript graph type %c (should be one of l, e, or c)",
@@ -736,7 +742,7 @@ mk_tmp_file (line, dir, base)
      char * base;
 #endif
 {
-  set_line (line, tempnam (dir, base));
+  set_line (line, tmpnam (0));
   return fopen (line->buf, "w");
 }
 
@@ -1232,6 +1238,7 @@ spew_for_ps ()
   struct line shell_script;
   struct line gp_script;
   init_line (&shell_script);
+  init_line (&gp_script);
   graph_spew_with_parameters (&shell_script, &gp_script, 0, "", "#data",
 			      "#plot", "#sh", 1); 
   splicen_line (&shell_script, " ", 1, 0);
