@@ -39,7 +39,7 @@ char *init_cmds[] =
   "create-keymap generic-main universal",
   "",
   "# This is the keymap in force at the top level when no command arguments are",
-  "# being editted.",
+  "# being edited.",
   "create-keymap main generic-main",
   "",
   "# The keymap after a M- or ESC prefix in main:",
@@ -125,8 +125,8 @@ char *init_cmds[] =
   "bind-key edit-ansi meta-edit-ansi ^[",
   "bind-key meta-edit-ansi up-cell-and-edit A",
   "bind-key meta-edit-ansi down-cell-and-edit B",
-  "bind-key meta-edit-ansi left-cell-and-edit C",
-  "bind-key meta-edit-ansi right-cell-and-edit D",
+  "bind-key meta-edit-ansi right-cell-and-edit C",
+  "bind-key meta-edit-ansi left-cell-and-edit D",
   "",
   "bind-key trolx goto-cell j",
   "bind-key meta goto-region j",
@@ -249,10 +249,10 @@ char *init_cmds[] =
   "bind-key meta delete-col k",
   "",
   "# Changing cell formulas",
-  "bind-key main edit-cell =",
+  "bind-key main set-cell =",
   "",
-  "# Some characters start editting the current cell and then are reinterpreted",
-  "# as editting commands:",
+  "# Some characters start editing the current cell and then are reinterpreted",
+  "# as editing commands:",
   "bind-set main goto-edit-cell a-z",
   "bind-set main goto-edit-cell A-Z",
   "bind-set main goto-edit-cell 0-9",
@@ -292,7 +292,7 @@ char *init_cmds[] =
   "bind-key meta goto-minibuffer ^",
   "bind-key trolx other-window o",
   "",
-  "# Command argument editting",
+  "# Command argument editing",
   "",
   "create-keymap read-string generic-main",
   "create-keymap meta-read-string generic-meta",
@@ -445,7 +445,7 @@ char *init_cmds[] =
   "bind-key view-info page-info-backwards -",
   "",
   "set-map-prompt view-info \\",
-  "+ (forward page)   - (backward page)   ESC (return to spreadsheet editting)",
+  "+ (forward page)   - (backward page)   ESC (return to spreadsheet editing)",
   "",
   "",
   "",
@@ -550,8 +550,8 @@ char *init_cmds[] =
   "",
   "bind-key psprint-commands set-page-size s",
   "bind-key psprint-commands set-page-size S",
-  "bind-key psprint-commands set-deault-ps-font f",
-  "bind-key psprint-commands set-deault-ps-font F",
+  "bind-key psprint-commands set-default-ps-font f",
+  "bind-key psprint-commands set-default-ps-font F",
   "bind-key psprint-commands psprint-region p",
   "bind-key psprint-commands psprint-region P",
   "",
@@ -599,7 +599,7 @@ run_init_cmds ()
 	  strcat (cmd, *p);
 	  ++p;
 	}
-      execute_command (cmd, 1);
+      execute_command (cmd);
       free (cmd);
     }
 }
