@@ -77,7 +77,7 @@ char *io_name;
 /* This should be updated for every release.
  * The file ANNOUNCE must be udpated as well.
  */
-const char oleo_version_string[] = "Oleo version 1.3.1";
+const char oleo_version_string[] = "Oleo version 1.5";
 
 /* This variable is non-zero if the spreadsheet has been changed in any way */ 
 int modified = 0;
@@ -125,7 +125,7 @@ static char * disclaimer[] =
   0
 };
 
-static char short_options[] = "Vqfh";
+static char short_options[] = "Vqfxh";
 static struct option long_options[] =
 {
   {"version", 0, NULL, 'V'},
@@ -1024,6 +1024,7 @@ main (argc, argv)
 	  {
 	  case 'V':
 	    fprintf  (stdout, "%s\n", oleo_version_string);
+	    exit (0);
 	    break;
 	  case 'q':
 	    spread_quietly = 1;
@@ -1036,10 +1037,16 @@ main (argc, argv)
 	    break;
 	  case 'h':
 	    show_usage ();
+	    exit (0);
 	    break;
 	  }
       }
   }
+  if (argc - optind > 1)
+    {
+      show_usage ();
+      exit (1);
+    }
   init_infinity ();
   init_mem ();
   init_eval ();
@@ -1088,15 +1095,6 @@ main (argc, argv)
 	++init_fpc;
     }
 
-  if (!init_fpc && !spread_quietly)
-    {
-      char ** msg;
-      fputs (oleo_version_string, stdout);
-      for (msg = disclaimer; *msg; ++msg)
-	fputs (*msg, stdout);
-      fflush (stdout);
-    }
-
   FD_ZERO (&read_fd_set);
   FD_ZERO (&read_pending_fd_set);
   FD_ZERO (&exception_fd_set);
@@ -1136,12 +1134,6 @@ main (argc, argv)
       run_init_cmds ();
     }
 
-  if (argc - optind > 1)
-    {
-      show_usage ();
-      exit (1);
-    }
-
   /* These probably don't all need to be ifdef, but
    * it is harmless.
    */
@@ -1218,7 +1210,7 @@ main (argc, argv)
 
   if (!command_line_file)
     run_string_as_macro
-      ("{pushback-keystroke}{builtin-help _NON_WARRANTY_}", 1);
+      ("{pushback-keystroke}{builtin-help _NON_WARRANTY_}");
   while (1)
     {
       setjmp (error_exception);
