@@ -40,7 +40,6 @@
 #include "display.h"
 #include "io-abstract.h"
 #include "regions.h"
-#include "math.h"
 #include "input.h"
 #include "info.h"
 
@@ -2285,7 +2284,8 @@ xio_open_display ()
 	thePort->fg_color_pixel = WhitePixel (thePort->dpy, thePort->screen);
   
   if (default_bg_color_name && 
-      XParseColor (thePort->dpy, thePort->color_map, default_bg_color_name, &thePort->bg_color) &&
+      XParseColor (thePort->dpy, thePort->color_map,
+		   default_bg_color_name, &thePort->bg_color) &&
       XAllocColor(thePort->dpy, thePort->color_map, &thePort->bg_color))
     thePort->bg_color_pixel = thePort->bg_color.pixel;
   else
@@ -2293,7 +2293,7 @@ xio_open_display ()
       thePort->bg_color_pixel = BlackPixel (thePort->dpy, thePort->screen);
     else
       if (default_bg_color_name && !stricmp (default_bg_color_name, "white"))
-	thePort->fg_color_pixel = WhitePixel (thePort->dpy, thePort->screen);
+	thePort->bg_color_pixel = WhitePixel (thePort->dpy, thePort->screen);
   
   thePort->window =
     XCreateSimpleWindow (thePort->dpy, DefaultRootWindow (thePort->dpy),
@@ -2304,8 +2304,12 @@ xio_open_display ()
   wmhints.input = True;
   XSetWMHints(thePort->dpy, thePort->window, &wmhints);
 
-  thePort->wm_delete_window = XInternAtom(thePort->dpy, "WM_DELETE_WINDOW", False);
-  (void) XSetWMProtocols( thePort->dpy, thePort->window, &thePort->wm_delete_window, 1);
+  thePort->wm_delete_window = XInternAtom(thePort->dpy,
+					  "WM_DELETE_WINDOW", False);
+#ifdef HAVE_XSETWMPROTOCOLS
+  XSetWMProtocols (thePort->dpy, thePort->window,
+		   &thePort->wm_delete_window, 1);
+#endif
   
   gcv.foreground = thePort->bg_color_pixel;
   gcv.background = thePort->bg_color_pixel;
