@@ -1,16 +1,16 @@
 
-/*  A Bison parser, made from posixtm.y  */
+/*  A Bison parser, made from ./posixtm.y  */
 
 #define YYBISON 1  /* Identify Bison output.  */
 
 #define	DIGIT	258
 
-#line 19 "posixtm.y"
+#line 19 "./posixtm.y"
 
 #ifdef __GNUC__
 #define alloca __builtin_alloca
 #else
-#ifdef sparc
+#if defined (HAVE_ALLOCA_H) || (defined(sparc) && (defined(sun) || (!defined(USG) && !defined(SVR4) && !defined(__svr4__))))
 #include <alloca.h>
 #else
 #ifdef _AIX
@@ -603,7 +603,7 @@ psxtreduce:
   switch (psxtn) {
 
 case 1:
-#line 62 "posixtm.y"
+#line 62 "./posixtm.y"
 {
 	         if (psxtvsp[-5] >= 1 && psxtvsp[-5] <= 12)
 		   t.tm_mon = psxtvsp[-5] - 1;
@@ -628,7 +628,7 @@ case 1:
 	       ;
     break;}
 case 2:
-#line 85 "posixtm.y"
+#line 85 "./posixtm.y"
 {
                    t.tm_year = psxtvsp[0];
 		   /* Deduce the century based on the year.
@@ -638,7 +638,7 @@ case 2:
 		 ;
     break;}
 case 3:
-#line 92 "posixtm.y"
+#line 92 "./posixtm.y"
 {
                             t.tm_year = psxtvsp[-1] * 100 + psxtvsp[0];
 			    if (t.tm_year < 1900) {
@@ -648,7 +648,7 @@ case 3:
 			  ;
     break;}
 case 4:
-#line 99 "posixtm.y"
+#line 99 "./posixtm.y"
 {
                     time_t now;
 		    struct tm *tmp;
@@ -660,13 +660,13 @@ case 4:
 		  ;
     break;}
 case 5:
-#line 110 "posixtm.y"
+#line 110 "./posixtm.y"
 {
                         t.tm_sec = 0;
 		      ;
     break;}
 case 6:
-#line 113 "posixtm.y"
+#line 113 "./posixtm.y"
 {
 	                  if (psxtvsp[0] >= 0 && psxtvsp[0] <= 61)
 			    t.tm_sec = psxtvsp[0];
@@ -676,7 +676,7 @@ case 6:
 			;
     break;}
 case 7:
-#line 122 "posixtm.y"
+#line 122 "./posixtm.y"
 {
                           psxtval = psxtvsp[-1] * 10 + psxtvsp[0];
 			;
@@ -876,7 +876,7 @@ psxterrhandle:
   psxtstate = psxtn;
   goto psxtnewstate;
 }
-#line 126 "posixtm.y"
+#line 126 "./posixtm.y"
 
 static int
 psxtlex ()
