@@ -39,30 +39,16 @@ static void add_ref_fm (struct ref_fm **, CELLREF, CELLREF);
 static void flush_ref_fm (struct ref_fm **, CELLREF, CELLREF);
 static void flush_range_ref (struct rng *, CELLREF, CELLREF);
 extern void shift_formula (int r, int c, int dn, int ov);
-#ifdef SPLIT_REFS
-/* These two are tunable paramaters */
-#define REF_START	3
-#define REF_INC		*=2
-#else
 static void flush_ref_to (struct ref_to **);
 static void flush_fm_ref (struct ref_fm *);
-#endif /* SPLIT_REFS */
-
 #else /* !__STDC__ */
-
 static void add_ref_fm ();
 static void flush_ref_fm ();
 static void flush_range_ref ();
 extern void shift_formula ();
 
-#ifdef SPLIT_REFS
-/* These two are tunable paramaters */
-#define REF_START	3
-#define REF_INC		*=2
-#else
 static void flush_ref_to ();
 static void flush_fm_ref ();
-#endif /* SPLIT_REFS */
 #endif /* __STDC__ */
 
 /* More tunable paramaters */
@@ -512,6 +498,7 @@ move_cell (rf, cf, rt, ct)
   my_cell = 0;
 }
 
+/* Used only in regions.c for copy_region. */
 #ifdef __STDC__
 void
 copy_cell (CELLREF rf, CELLREF cf, CELLREF rt, CELLREF ct)
@@ -759,7 +746,7 @@ copy_cell (rf, cf, rt, ct)
 }
 
 /* Take away the value of CP.  This means getting rid of all the references
-   to it, etc.
+ * to it, etc.
  */
 #ifdef __STDC__
 void
@@ -872,11 +859,7 @@ flush_old_value ()
 	      break;
 	    }
 	}
-#ifdef SPLIT_REFS
-      ref->refs_used = 0;
-#else
       flush_ref_to (&(my_cell->cell_refs_to));
-#endif
     }
   if (my_cell->cell_formula)
     {
@@ -890,6 +873,9 @@ flush_old_value ()
 
 /* --------- Routines for dealing with cell references to other cells ------ */
 
+
+/* Record in the argument cell that cur_row/col depends on it. */
+
 #ifdef __STDC__
 void
 add_ref (CELLREF row, CELLREF col)
@@ -906,6 +892,9 @@ add_ref (row, col)
   add_ref_fm (&(other_cell->cell_refs_from), cur_row, cur_col);
 }
 
+/* like add_ref, except over a range of arguments and with memory
+ * management weirdness. 
+ */
 #ifdef __STDC__
 void
 add_range_ref (struct rng *rng)
@@ -978,15 +967,12 @@ flush_range_ref (rng, rr, cc)
 #endif
 {
   CELL *other_cell;
-#ifndef SPLIT_REFS
   struct ref_fm *oldref, *newref;
   struct ref_fm nonref;
-#endif
   /* This is horribly inefficient:  Simply referencing a cell makes
 	   it appear.  On the other hand, there is no other easy way to deal
 	   with the references to the cells (That I know of, anyway) */
   find_cells_in_range (rng);
-#ifndef SPLIT_REFS
   /* Be efficient:  If cells in the range currently have the same
 	   references, they'll have the same references afterward, so just
 	   adjust the refcounts */
@@ -1027,25 +1013,8 @@ flush_range_ref (rng, rr, cc)
       else
 	flush_ref_fm (&(other_cell->cell_refs_from), rr, cc);
     }
-#else
-  while (other_cell = next_cell_in_range ())
-    flush_ref_fm (&(other_cell->cell_refs_from), rr, cc);
-#endif
 }
 
-/* SPLIT_REFS should probably go away, since it is a performance loss.
-   When it is defined, we allocate a a reference structure for each cell with
-   references, and update them individually.
-
-   The default is to allocate one reference structure for each *different*
-   reference, and have multiple cells point to it.  We use reference counts
-   to keep track of when to delete the reference structure.  This would
-   appear to be a performance loss, but because of the increased efficiency
-   in referencing ranges, it may actually be faster.  It also uses *far* less
-   memory than SPLIT_REFS */
-
-
-#ifndef SPLIT_REFS
 #ifdef __TURBOC__
 #define FM_HASH_NUM 51
 #define TO_HASH_NUM 13
@@ -1181,7 +1150,9 @@ flush_fm_ref (old)
 	fm_list[hash] = old->refs_next;
       else
 	{
-	  for (tmp = fm_list[hash]; tmp && tmp->refs_next != old; tmp = tmp->refs_next)
+	  for (tmp = fm_list[hash];
+	       tmp && tmp->refs_next != old;
+	       tmp = tmp->refs_next)
 	    ;
 #ifdef TEST
 	  if (!tmp)
@@ -1190,7 +1161,8 @@ flush_fm_ref (old)
 	      return;
 	    }
 #endif
-	  tmp->refs_next = old->refs_next;
+	  if (tmp)
+	    tmp->refs_next = old->refs_next;
 	}
       free (old);
     }
@@ -1587,198 +1559,6 @@ ref_stats ()
   io_text_line ("to: %d refs, max_length %d, shared %d, saved %d, zero_ref %d, missed %d\n", rt_num, rt_max, rt_shared, rt_saved, rt_zero, to_misses);
 }
 
-#endif
-#else
-
-#ifdef __STDC__
-static void
-add_ref_fm (struct ref_fm **where, CELLREF r, CELLREF c)
-#else
-static void
-add_ref_fm (where, r, c)
-     struct ref_fm **where;
-     CELLREF r;
-     CELLREF c;
-#endif
-{
-  struct ref_fm *ref;
-
-  ref = *where;
-  if (!ref)
-    {
-      *where = ref = ck_malloc (sizeof (struct ref_fm) + (REF_START - 1) * sizeof (struct ref_array));
-      ref->refs_alloc = REF_START;
-      ref->refs_used = 0;
-    }
-  else if (ref->refs_alloc == ref->refs_used)
-    {
-      ref->refs_alloc REF_INC;
-      *where = ref = ck_realloc (ref, sizeof (struct ref_fm) + (ref->refs_alloc - 1) * sizeof (struct ref_array));
-    }
-  ref->fm_refs[ref->refs_used].ref_row = r;
-  ref->fm_refs[ref->refs_used].ref_col = c;
-  ref->refs_used++;
-}
-
-#ifdef __STDC__
-static void
-flush_ref_fm (struct ref_fm **where, CELLREF r, CELLREF c)
-#else
-static void
-flush_ref_fm (where, r, c)
-     struct ref_fm **where;
-     CELLREF r;
-     CELLREF c;
-#endif
-{
-  int n;
-  struct ref_fm *ref;
-
-  ref = *where;
-#ifdef TEST
-  if (!ref)
-    {
-      io_error_msg ("%s->No refs in flush_ref_fm(%d,%d)", cell_name (cur_row, cur_col), r, c);
-      return;
-    }
-#endif
-  for (n = 0; n < ref->refs_used; n++)
-    if (ref->fm_refs[n].ref_row == r && ref->fm_refs[n].ref_col == c)
-      {
-	ref->fm_refs[n] = ref->fm_refs[ref->refs_used - 1];
-	--(ref->refs_used);
-	return;
-      }
-#ifdef TEST
-  io_error_msg ("%s->Can't flush_ref_fm(%d,%d)", cell_name (cur_row, cur_col), r, c);
-  return;
-#endif
-}
-
-#ifdef __STDC__
-void
-add_ref_to (int whereto)
-#else
-void
-add_ref_to (whereto)
-     int whereto;
-#endif
-{
-  struct ref_to *ref;
-
-  ref = my_cell->cell_refs_to;
-  if (!ref)
-    {
-      my_cell->cell_refs_to = ref = ck_malloc (sizeof (struct ref_to) + (REF_START - 1) * sizeof (unsigned char));
-      ref->refs_alloc = REF_START;
-      ref->refs_used = 0;
-    }
-  else if (ref->refs_alloc == ref->refs_used)
-    {
-      ref->refs_alloc REF_INC;
-      my_cell->cell_refs_to = ref = ck_realloc (ref, sizeof (struct ref_to) +
-			    (ref->refs_alloc - 1) * sizeof (unsigned char));
-    }
-  ref->to_refs[ref->refs_used] = whereto;
-  ref->refs_used++;
-}
-
-#ifdef TEST
-
-void
-dbg_print_ref_fm (rf)
-     struct ref_fm *rf;
-{
-  int nr;
-  char *bufp;
-
-  if (rf)
-    {
-      io_text_line ("fm %p: alloc %u  used %u",
-		    rf, rf->refs_alloc, rf->refs_used);
-      for (nr = 0, bufp = print_buf; nr < rf->refs_used; nr++)
-	{
-	  (void) sprintf (bufp, " %s", cell_name (rf->fm_refs[nr].ref_row, rf->fm_refs[nr].ref_col));
-	  if (nr % 10 == 9)
-	    {
-	      io_text_line (print_buf);
-	      bufp = print_buf;
-	    }
-	  else
-	    bufp += strlen (bufp);
-	}
-      if (nr % 10)
-	io_text_line (print_buf);
-    }
-}
-
-void
-dbg_print_ref_to (rt, form)
-     struct ref_to *rt;
-     unsigned char *form;
-{
-  int nr;
-  char *bufp;
-
-  if (rt)
-    {
-      io_text_line ("to %p:  alloc %u  used %u",
-		    rt, rt->refs_alloc, rt->refs_used);
-      for (nr = 0, bufp = print_buf; nr < rt->refs_used; nr++)
-	{
-	  (void) sprintf (bufp, " %3d (%#4x)", rt->to_refs[nr], form[rt->to_refs[nr]]);
-	  if (nr % 7 == 6)
-	    {
-	      io_text_line (print_buf);
-	      bufp = print_buf;
-	    }
-	  else
-	    bufp += strlen (bufp);
-	}
-      if (nr % 7)
-	io_text_line (print_buf);
-    }
-}
-
-void
-ref_stats ()
-{
-  CELL *cp;
-
-  int rf_num = 0;
-  int rf_zero = 0;
-  int rf_biggest = 0;
-
-  int rt_num = 0;
-  int rt_zero = 0;
-  int rt_biggest = 0;
-
-  find_cells_in_range (&all_rng);
-  while (cp = next_cell_in_range ())
-    {
-      if (cp->cell_refs_from)
-	{
-	  if (cp->cell_refs_from->refs_used > rf_biggest)
-	    rf_biggest = cp->cell_refs_from->refs_used;
-	  if (cp->cell_refs_from->refs_used == 0)
-	    rf_zero++;
-	  rf_num++;
-	}
-      if (cp->cell_refs_to)
-	{
-	  if (cp->cell_refs_to->refs_used > rt_biggest)
-	    rt_biggest = cp->cell_refs_to->refs_used;
-	  if (cp->cell_refs_to->refs_used == 0)
-	    rt_zero++;
-	  rt_num++;
-	}
-    }
-  io_text_line ("from: %d refs, biggest %d, zero_ref %d\n", rf_num, rf_biggest, rf_zero);
-  io_text_line ("to: %d refs, biggest %d,zero_ref %d\n", rt_num, rt_biggest, rt_zero);
-}
-
-#endif
-
 #endif
 
 /* ------------- Routines for dealing with moving cells -------------------- */
@@ -2530,12 +2310,8 @@ flush_all_timers ()
 {
   if (timer_active)
     {
-#ifdef SPLIT_REFS
-      timer_cells->refs_used = 0;
-#else
       flush_fm_ref (timer_cells);
       timer_cells = 0;
-#endif
       timer_active = 0;
     }
 }
@@ -2981,10 +2757,6 @@ flush_var (name, var)
      struct var *var;
 #endif
 {
-#ifdef SPLIT_REFS
-  if (var->var_ref_fm)
-    free (var->var_ref_fm);
-#endif
   free (var);
 }
 
