@@ -40,10 +40,7 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #endif /* not (DIRENT or _POSIX_VERSION) */
 
 #ifdef __STDC__
-#define CONST const
 #undef NULL
-#else
-#define CONST
 #endif
 
 #include <ctype.h>
@@ -200,7 +197,7 @@ __fp_name (fp)
 void
 __set_fp (fp, name, flag)
      FILE *fp;
-     CONST char *name;
+     const char *name;
      int flag;
 {
   if (__id_s == 0)
@@ -237,8 +234,8 @@ __set_fp (fp, name, flag)
 /* Open a file or a pipe */
 FILE *
 xopen (name, mode)
-     CONST char *name;
-     CONST char *mode;
+     const char *name;
+     const char *mode;
 {
   int flag = 0;
   FILE *ret;
@@ -263,7 +260,7 @@ xopen (name, mode)
 FILE *
 fopen_with_backup (name, mode)
      char *name;
-     CONST char *mode;
+     const char *mode;
 {
   char *newname;
   struct stat stat_buf;
@@ -298,7 +295,7 @@ fopen_with_backup (name, mode)
 		fclose (c_in);
 		return 0;
 	      }
-	    fchmod (fd, stat_buf.st_mode);
+	    chmod (newname, stat_buf.st_mode);
 	    c_out = fdopen (fd, "w");
 	    if (!c_out)
 	      {
@@ -330,7 +327,7 @@ fopen_with_backup (name, mode)
   {
     FILE * ret = fopen (name, mode);
     if (ret && old_file)
-      fchmod (fileno (ret), stat_buf.st_mode);
+      chmod (name, stat_buf.st_mode);
     return ret;
   }
 }
@@ -338,8 +335,8 @@ fopen_with_backup (name, mode)
 /* Open a file or a pipe, creating a backup file if it's a file */
 FILE *
 xopen_with_backup (name, mode)
-     CONST char *name;
-     CONST char *mode;
+     const char *name;
+     const char *mode;
 {
   int flag;
   FILE *ret;
@@ -406,6 +403,19 @@ ck_malloc (size)
   return ret;
 }
 
+
+#ifdef __STDC__
+void
+ck_free (void * mem)
+#else
+void
+ck_free (mem)
+     void * mem;
+#endif
+{
+  if (mem) free (mem);
+}
+
 #ifdef __STDC__
 char *
 ck_savestr (char *str)
@@ -608,7 +618,7 @@ size_stack (bb)
 #ifndef HAVE_STRDUP
 char *
 strdup (str)
-     CONST char *str;
+     const char *str;
 {
   char *ret;
 
@@ -629,12 +639,12 @@ stricmp (const char * s1, const char * s2)
 #else
 int
 stricmp (s1, s2)
-     CONST char *s1;
-     CONST char *s2;
+     const char *s1;
+     const char *s2;
 #endif
 {
-  register CONST char *scan1;
-  register CONST char *scan2;
+  register const char *scan1;
+  register const char *scan2;
   register char chr1, chr2;
 
   scan1 = s1;
@@ -672,13 +682,13 @@ strincmp (const char * s1, const char * s2, size_t n)
 #else
 int
 strincmp (s1, s2, n)
-     CONST char *s1;
-     CONST char *s2;
+     const char *s1;
+     const char *s2;
      size_t n;
 #endif
 {
-  register CONST char *scan1;
-  register CONST char *scan2;
+  register const char *scan1;
+  register const char *scan2;
   register size_t count;
   register char chr1, chr2;
 
@@ -716,15 +726,15 @@ strincmp (s1, s2, n)
 #ifndef HAVE_STRSTR
 #ifdef __STDC__
 char *
-strstr (CONST char *s, CONST char *wanted)
+strstr (const char *s, const char *wanted)
 #else
 char *
 strstr (s, wanted)
-     CONST char *s;
-     CONST char *wanted;
+     const char *s;
+     const char *wanted;
 #endif
 {
-  register CONST char *scan;
+  register const char *scan;
   register size_t len;
   register char firstc;
 
