@@ -637,7 +637,7 @@ page_scroll_axis (cur, over, total, get, ret1, ret2, offp)
   int n_over;
   CELLREF lo, hi;
   int tot;
-  int ww;
+  int ww = 0;
 
   n_over = 0;
   lo = hi = MIN_ROW;
@@ -789,7 +789,7 @@ io_set_input_status (inp, stat, redraw)
 	{
 	  if (inpv > statv)
 	    {
-	      new_inp = user_status ? status_rows : 0;
+	      new_inp = new_us ? status_rows : 0;
 	      new_stat = 0;
 	    }
 	  else
@@ -799,8 +799,8 @@ io_set_input_status (inp, stat, redraw)
 	    }
 	  if (inpsgn < 0)
 	    {
-	      new_stat = LINES - status - status_rows;
-	      new_inp = LINES - input - input_rows;
+	      new_stat = LINES - new_stat - status_rows;
+	      new_inp = LINES - new_inp - input_rows;
 	    }
 	}
       if (redraw)
@@ -840,7 +840,7 @@ io_set_input_status (inp, stat, redraw)
 		  int top =
 		  wins[x].win_down - win_label_rows (&wins[x]);
 		  if (cell_top == top)
-		    wins[x].numr += vchange;
+		    wins[x].numr -= vchange;
 		}
 	    }
 	  if (vchange)
